@@ -48,7 +48,7 @@ final class CGMyOrders extends CGExtensions
 {
   public function GetName() { return get_class($this); }
   public function GetFriendlyName() { return $this->Lang('friendlyname'); }
-  public function GetVersion() { return '1.1'; }
+  public function GetVersion() { return '1.2'; }
   public function GetHelp() { return file_get_contents(__DIR__.'/help.inc'); }
   public function GetAuthor() { return 'Robert Campbell'; }
   public function GetAuthorEmail() { return 'calguy1000@cmsmadesimple.org'; }
@@ -62,11 +62,11 @@ final class CGMyOrders extends CGExtensions
   }
   public function GetDependencies()
   {
-    return array('CGExtensions'=>'1.32.5',
-		 'CGEcommerceBase'=>'1.4',
-		 'Orders'=>'1.13.6');
+    return array('CGExtensions'=>'1.36',
+		 'CGEcommerceBase'=>'1.4.3',
+		 'Orders'=>'1.15.2');
   }
-  public function MinimumCMSVersion() {  return '1.11.4'; }
+  public function MinimumCMSVersion() {  return '1.11.7'; }
   public function InstallPostMessage() { return $this->Lang('postinstall'); }
   public function UninstallPostMessage() { return $this->Lang('postuninstall'); }
   public function UninstallPreMessage() { return $this->Lang('really_uninstall'); }
@@ -86,12 +86,14 @@ final class CGMyOrders extends CGExtensions
     $this->CreateParameter('action','',$this->Lang('param_action'));
     $this->CreateParameter('useridtemplate','',$this->Lang('param_useridtemplate'));
     $this->CreateParameter('orderlisttemplate','',$this->Lang('param_orderlisttemplate'));
+    $this->CreateParameter('reordertemplate','',$this->Lang('param_reordertemplate'));
     $this->CreateParameter('invoicetemplate','',$this->Lang('param_invoicetemplate'));
     $this->CreateParameter('order','',$this->Lang('param_order'));
     $this->CreateParameter('email','',$this->Lang('param_email'));
 
     $this->SetParameterType('useridtemplate',CLEAN_STRING);
     $this->SetParameterType('orderlisttemplate',CLEAN_STRING);
+    $this->SetParameterType('reordertemplate',CLEAN_STRING);
     $this->SetParameterType('invoicetemplate',CLEAN_STRING);
 
     $this->SetParameterType('order',CLEAN_INT);
