@@ -8,6 +8,7 @@ $lang['amtdue'] = 'Amt. Due';
 $lang['created'] = 'Created';
 
 #D
+$lang['description'] = 'Description';
 $lang['dflt_templates'] = 'Default Templates';
 
 #E
@@ -23,6 +24,7 @@ $lang['friendlyname'] = 'Customer Order Viewer';
 
 #I
 $lang['info_orderlist_template'] = 'This template provides a summary view of orders that match the criteria specified';
+$lang['info_reorder_template'] = 'This template provides a report of what items were added to the cart, and what items were not when reordering a previous order';
 $lang['info_useridform_template'] = 'This template provides a form by which users can be identified against orders, so that a list can be provided';
 $lang['invoice'] = 'Invoice';
 $lang['items'] = 'Items';
@@ -44,39 +46,55 @@ $lang['modified'] = 'Modified';
 $lang['orderlist_template'] = 'Order List Templates';
 
 #P
-$lang['param_action'] = 'Specify the action to execute.   Possible values are: default,userid,view_invoice.<br/>
+$lang['param_action'] = 'Specify the action to execute.   Possible values are: default,userid,view_invoice,reorder.<br/>
 The default action will provide an order list that matches the criteria specified. By default it will use the currently logged in FEU user id.<br/>
-The userid action can be used when allowing anonymous checkout to provide a simple form to allow the user to enter their email address for order matching.<br/>
+The userid action can be used when allowing anonymous checkout to provide a simple form to allow the user to enter their email address for order matching.  The reorder action can be used to allow reordering available products from a previous order.<br/>
 The view_order action can be used to generate a report for a single order.</p>';
 $lang['param_email'] = 'Applicable only to the default action, this parameter allows specifying an email address to match orders against.  If this parameter is used, then the users FEU uid will not be used.  This parameter is usually passed from the userid action.';
 $lang['param_invoicetemplate'] = 'Applicable only to the view_invoice action, this parameter allows specifying a non default invoice template (invoice templates are located in the Orders module) to use when displaying an invoice';
-$lang['param_order'] = 'Applicable only to the view_invoice action, this parameter allows specifing an integer order number to view.  This parameter is usually passed from the default (order list) action.';
+$lang['param_order'] = 'Applicable to the view_invoice and reorder actions, this parameter allows specifing an integer order number to view (or reorder).  This parameter is usually passed from the default (order list) action.';
 $lang['param_orderlisttemplate'] = 'Applicable only to the default action (though it can be passed through from the userid action).  This parameter allows specifying by name, a non default orderlist tempalte to use when displaying a list of orders.';
-$lang['param_useridtemplate'] = 'Applicable only to the userid action, this parameter allows specifying the name of a non-default userid template.  If not specified, the current default userid template will be specified.';
+$lang['param_reordertemplate'] = 'Applicable only to the reorder action, this parameter allows specifying the name of a non-defalt reorder template.  If not specified, the current default reorder template will be used';
+$lang['param_useridtemplate'] = 'Applicable only to the userid action, this parameter allows specifying the name of a non-default userid template.  If not specified, the current default userid template will be used.';
 $lang['postinstall'] = 'Module successfully installed.  Please visit the modules admin panel and adjust necessary settings';
 $lang['postuninstall'] = 'CGMyOrderrs module and all associated ata has been removed';
+$lang['product_id'] = 'Product Id';
+$lang['prompt_allow_reorder'] = 'Allow re-ordering';
 $lang['prompt_enteremail'] = 'Enter the email address used in the billing stage of the checkout process';
 $lang['prompt_max_invoice_views'] = 'Maximum number of times that an invoice can be viewed (enter 0 for unlimited)';
 $lang['prompt_invoice_rpt_page'] = 'What page should be used for the invoice display';
 
 #Q
+$lang['quantity'] = 'Quantity';
 
 #R
 $lang['really_uninstall'] = 'Are you sure you really want to uninstall this module?  Doing so may break functionality on a running website.';
+$lang['reorderlist_header'] = 'Reorder Report';
+$lang['reorderlist_ordered'] = 'These products were successfully added to your cart';
+$lang['reorder_check_cart'] = 'The possible items have been added to your cart.  Please view your cart to confirm the items you want to order';
+$lang['reorder_notfound_items'] = 'The following items could not be added to your cart because they are unavailable at this time';
+$lang['reorder_noitems_found'] = 'Sorry. However none of the products in your order are available for reorder at this time';
+$lang['reorder_this'] = 'Re-order these items';
+$lang['reorder_template'] = 'Reorder Templates';
 
 #S
 $lang['settings'] = 'Settings';
+$lang['sku'] = 'SKU';
 $lang['status'] = 'Status';
 $lang['submit'] = 'Submit';
 
 #T
 $lang['title_orderlist_template'] = 'Order List Template';
+$lang['title_reorder_template'] = 'Reorder Report Template';
 $lang['title_sysdflt_orderlist_template'] = 'System Default Order List Template';
+$lang['title_sysdflt_reorder_template'] = 'System Default Reorder Report Template';
 $lang['title_sysdflt_useridform_template'] = 'System Default User Identification Form Template';
 $lang['title_useridform_template'] = 'User Identification Form Template';
 $lang['total'] = 'Total';
 
 #U
+$lang['unit_discount'] = 'Unit Discount';
+$lang['unit_price'] = 'Unit Price';
 $lang['userid_form_template'] = 'User Identification Form Templates';
 
 #V
